# Christopher Pierce - Public Code

Hi there! This is a monorepo with a selection of my personal code and projects that I've decided to share with the public.

## What's Inside

This repository contains utility functions, tools, and projects that I've found useful in my own work. Key areas include:
- Tools for interacting with file formats related to building surrogate models in accelerator physics
- Plotting tools for accelerator physics data
- Helper code for the optimization library `xopt`
- Wrapper classes and tools for using my library [ParetoBench](https://github.com/electronsandstuff/ParetoBench) with optimization frameworks in python

## Installation

The python utilities can be installed via pip:
```bash
pip install electronsandstuff
```
